## angular-timer — A simple, re-usable, inter-operable timer directive [![Build Status](https://travis-ci.org/siddii/angular-timer.png)](https://travis-ci.org/siddii/angular-timer)

### Getting started
With any of the following options...
* Download the latest script file - https://raw.github.com/siddii/angular-timer/master/dist/angular-timer.min.js
* Clone the repo - `git@github.com:siddii/angular-timer.git`
* Install angular-timer using [Bower](http://bower.io) - `bower install angular-timer`

### Running locally
Using [Grunt](http://gruntjs.com/) type `grunt` from command line, the default task will open index.html page in your
default browser

### Running tests
Following command will run both unit & End-to-End (e2e) tests
```bash
grunt tests
```


